==> QupZilla-2.2.1.tar.xz: QupZilla-2.2.1/src/plugins/TabManager/translations/da_DK.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="da_DK" version="2.1">
<context>
    <name>TabManagerSettings</name>
    <message>
        <location filename="../tabmanagersettings.ui" line="14"/>
        <source>Tab Manager Settings</source>
        <translation>Indstillinger for fanebladshåndtering</translation>
    </message>
    <message>
        <location filename="../tabmanagersettings.ui" line="20"/>
        <source>View</source>
        <translation>Visning</translation>
    </message>
    <message>
        <location filename="../tabmanagersettings.ui" line="26"/>
        <source>Please select view type:</source>
        <translation>Vælg venligst visningstype:</translation>
    </message>
    <message>
        <location filename="../tabmanagersettings.ui" line="33"/>
        <source>SideBar</source>
        <translation>Sidepanel</translation>
    </message>
    <message>
        <location filename="../tabmanagersettings.ui" line="40"/>
        <source>Window</source>
        <translation>Vindue</translation>
    </message>
    <message>
        <location filename="../tabmanagersettings.ui" line="47"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Note:&lt;/span&gt; The &amp;quot;Window&amp;quot; type is recommended for managing lots of windows/tabs.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Bemærk:&lt;/span&gt; Typen &amp;quot;Vindue&amp;quot; anbefales til håndtering af mange vinduer/faneblade.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../tabmanagersettings.ui" line="60"/>
        <source>Use TabManager plugin as replacement for main TabBar.</source>
        <translation>Brug TabManager-plugin som erstatning til primær fanebladslinje.</translation>
    </message>
</context>
<context>
    <name>TabManagerWidget</name>
    <message>
        <location filename="../tabmanagerwidget.ui" line="14"/>
        <source>Tab Manager</source>
        <translation>Fanebladshåndtering</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="98"/>
        <source>Local File System:</source>
        <translation>Lokale filsystem:</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="101"/>
        <source>QupZilla:</source>
        <translation>QupZilla:</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="104"/>
        <source> [FTP]</source>
        <translation> [FTP]</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="250"/>
        <source>Group by</source>
        <translation>Gruppér efter</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="251"/>
        <source>&amp;Window</source>
        <translation>&amp;Vindue</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="256"/>
        <source>&amp;Domain</source>
        <translation>&amp;Domæne</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="261"/>
        <source>&amp;Host</source>
        <translation>&amp;Vært</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="269"/>
        <source>&amp;Show side by side</source>
        <translation>&amp;Vis side om side</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="275"/>
        <source>&amp;Detach checked tabs</source>
        <translation>&amp;Løsriv tilvalgte faneblade</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="276"/>
        <source>Book&amp;mark checked tabs</source>
        <translation>Sæt &amp;bogmærke for tilvalgte faneblade</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="277"/>
        <source>&amp;Close checked tabs</source>
        <translation>&amp;Luk tilvalgte faneblade</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="528"/>
        <source>Choose folder for bookmarks:</source>
        <translation>Vælg mappe til faneblade:</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="529"/>
        <source>Bookmark Selected Tabs</source>
        <translation>Sæt bogmærke for tilvalgte faneblade</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="646"/>
        <source>Window %1</source>
        <translation>Vindue %1</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="647"/>
        <source>Double click to switch</source>
        <translation>Dobbeltklik for at skifte</translation>
    </message>
</context>
<context>
    <name>TabManagerWidgetController</name>
    <message>
        <location filename="../tabmanagerwidgetcontroller.cpp" line="46"/>
        <location filename="../tabmanagerwidgetcontroller.cpp" line="51"/>
        <source>Tab Manager</source>
        <translation>Fanebladshåndtering</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidgetcontroller.cpp" line="79"/>
        <source>Show Tab Manager</source>
        <translation>Vis fanebladshåndtering</translation>
    </message>
</context>
</TS>

==> QupZilla-2.2.6.tar.xz: QupZilla-2.2.6/src/plugins/TabManager/translations/da_DK.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="da_DK" version="2.1">
<context>
    <name>TabManagerButton</name>
    <message>
        <location filename="../tabmanagerwidgetcontroller.cpp" line="50"/>
        <source>Tab Manager button</source>
        <translation>Fanebladshåndtering-knap</translation>
    </message>
</context>
<context>
    <name>TabManagerSettings</name>
    <message>
        <location filename="../tabmanagersettings.ui" line="14"/>
        <source>Tab Manager Settings</source>
        <translation>Indstillinger for fanebladshåndtering</translation>
    </message>
    <message>
        <location filename="../tabmanagersettings.ui" line="20"/>
        <source>View</source>
        <translation>Visning</translation>
    </message>
    <message>
        <location filename="../tabmanagersettings.ui" line="26"/>
        <source>Please select view type:</source>
        <translation>Vælg venligst visningstype:</translation>
    </message>
    <message>
        <location filename="../tabmanagersettings.ui" line="33"/>
        <source>SideBar</source>
        <translation>Sidepanel</translation>
    </message>
    <message>
        <location filename="../tabmanagersettings.ui" line="40"/>
        <source>Window</source>
        <translation>Vindue</translation>
    </message>
    <message>
        <location filename="../tabmanagersettings.ui" line="47"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Note:&lt;/span&gt; The &amp;quot;Window&amp;quot; type is recommended for managing lots of windows/tabs.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Bemærk:&lt;/span&gt; Typen &amp;quot;Vindue&amp;quot; anbefales til håndtering af mange vinduer/faneblade.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../tabmanagersettings.ui" line="60"/>
        <source>Use TabManager plugin as replacement for main TabBar.</source>
        <translation>Brug TabManager-plugin som erstatning til primær fanebladslinje.</translation>
    </message>
</context>
<context>
    <name>TabManagerWidget</name>
    <message>
        <location filename="../tabmanagerwidget.ui" line="14"/>
        <source>Tab Manager</source>
        <translation>Fanebladshåndtering</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="110"/>
        <source>Local File System:</source>
        <translation>Lokale filsystem:</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="113"/>
        <source>QupZilla:</source>
        <translation>QupZilla:</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="116"/>
        <source> [FTP]</source>
        <translation> [FTP]</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="301"/>
        <source>Group by</source>
        <translation>Gruppér efter</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="302"/>
        <source>&amp;Window</source>
        <translation>&amp;Vindue</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="307"/>
        <source>&amp;Domain</source>
        <translation>&amp;Domæne</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="312"/>
        <source>&amp;Host</source>
        <translation>&amp;Vært</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="320"/>
        <source>&amp;Show side by side</source>
        <translation>&amp;Vis side om side</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="326"/>
        <source>&amp;Detach checked tabs</source>
        <translation>&amp;Løsriv tilvalgte faneblade</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="327"/>
        <source>Book&amp;mark checked tabs</source>
        <translation>Sæt &amp;bogmærke for tilvalgte faneblade</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="328"/>
        <source>&amp;Close checked tabs</source>
        <translation>&amp;Luk tilvalgte faneblade</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="329"/>
        <source>&amp;Unload checked tabs</source>
        <translation>&amp;Afindlæs tilvalgte faneblade</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="581"/>
        <source>Choose folder for bookmarks:</source>
        <translation>Vælg mappe til faneblade:</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="582"/>
        <source>Bookmark Selected Tabs</source>
        <translation>Sæt bogmærke for tilvalgte faneblade</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="700"/>
        <source>Window %1</source>
        <translation>Vindue %1</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="701"/>
        <source>Double click to switch</source>
        <translation>Dobbeltklik for at skifte</translation>
    </message>
</context>
<context>
    <name>TabManagerWidgetController</name>
    <message>
        <location filename="../tabmanagerwidgetcontroller.cpp" line="68"/>
        <location filename="../tabmanagerwidgetcontroller.cpp" line="73"/>
        <location filename="../tabmanagerwidgetcontroller.cpp" line="99"/>
        <source>Tab Manager</source>
        <translation>Fanebladshåndtering</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidgetcontroller.cpp" line="100"/>
        <source>Show Tab Manager</source>
        <translation>Vis fanebladshåndtering</translation>
    </message>
</context>
</TS>
